==> vue-corator-1.5.0.tgz: package/lib/vue-corator.js <==
import Vue from 'vue';
import { createDecorator } from 'vue-class-component';
export function Style(refKey) {
    return createDecorator(function (options, key) {
        options.computed = options.computed || {};
        options.computed[key] = {
            cache: false,
            get: function () {
                // @ts-ignore
                return this.$refs[refKey || key].style;
            },
        };
    });
}
export function NextTick() {
    return function (target, key, descriptor) {
        var method = descriptor.value;
        descriptor.value = function () {
            Vue.nextTick(function () {
                method();
            });
        };
        var returnValue = descriptor.value;
        return descriptor.value();
    };
}
export function UniqueId(key) {
    return createDecorator(function (options, k) {
        options.computed = options.computed || {};
        options.computed[k] = {
            cache: false,
            get: function () {
                // @ts-ignore
                return [key || k] + '-' + this._uid;
            },
        };
    });
}
export function Render(componentName) {
    return function (target, key, descriptor) {
        var method = descriptor.value;
        var compiledTemplate = Vue.compile(method());
        var execParameta = /(?=\(([^)]*)\))(?=[^,]+)/g;
        var paramArray = execParameta.exec(method);
        var parameta = paramArray !== null ? paramArray[1].replace(/\s*/g, '') : ''; // remove space
        var props = parameta.split(',');
        var newComponent = {
            props: props,
            render: function (createElement) {
                return compiledTemplate.render.call(this, createElement);
            }
        };
        createDecorator(function (options, k) {
            options.components = options.components || {};
            options.components[componentName || key] = newComponent;
        })(target, key);
    };
}

==> vue-corator-1.5.2.tgz: package/lib/vue-corator.js <==
import Vue from 'vue';
import { createDecorator } from 'vue-class-component';
export function Style() {
    return function (target, key, descriptor) {
        var style = descriptor.value();
        var newComponent = {
            // @ts-ignore
            render: function (createElement) {
                return createElement('style', { attrs: { type: 'text/css', lang: 'css' } }, 
                // @ts-ignore
                [this.$slots.default || style]);
            }
        };
        createDecorator(function (options, k) {
            options.components = options.components || {};
            options.components.vStyle = newComponent;
        })(target, key);
    };
}
export function NextTick() {
    return function (target, key, descriptor) {
        var method = descriptor.value;
        descriptor.value = function () {
            Vue.nextTick(function () {
                method();
            });
        };
        var returnValue = descriptor.value;
        return descriptor.value();
    };
}
export function Render(componentName) {
    return function (target, key, descriptor) {
        var method = descriptor.value;
        var compiledTemplate = Vue.compile(method());
        var execParameta = /(?=\(([^)]*)\))(?=[^,]+)/g;
        var paramArray = execParameta.exec(method);
        var parameta = paramArray !== null ? paramArray[1].replace(/\s*/g, '') : ''; // remove space
        var props = parameta.split(',');
        var newComponent = {
            props: props,
            render: function (createElement) {
                return compiledTemplate.render.call(this, createElement);
            }
        };
        createDecorator(function (options, k) {
            options.components = options.components || {};
            options.components[componentName || key] = newComponent;
        })(target, key);
    };
}
export function ScopedId(key) {
    return createDecorator(function (options, k) {
        options.computed = options.computed || {};
        options.computed[k] = {
            cache: false,
            get: function () {
                // @ts-ignore
                return this.$options._scopeId;
            },
        };
    });
}
